SystemOrganization addCategory: #ConfigurationOfSimplePersistence!

Object subclass: #ConfigurationOfSimplePersistence
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSimplePersistence'!

!ConfigurationOfSimplePersistence commentStamp: 'SeanDeNigris 1/16/2013 14:53' prior: 0!
ConfigurationOfSimplePersistence project development load.!

!ConfigurationOfSimplePersistence class methodsFor: 'development support' stamp: 'SeanDeNigris 6/6/2012 23:11'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSimplePersistence class methodsFor: 'private' stamp: 'SeanDeNigris 6/6/2012 23:11'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSimplePersistence class methodsFor: 'private' stamp: 'SeanDeNigris 6/6/2012 23:11'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSimplePersistence class methodsFor: 'private' stamp: 'SeanDeNigris 6/6/2012 23:11'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSimplePersistence class methodsFor: 'metacello tool support' stamp: 'SeanDeNigris 6/6/2012 23:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSimplePersistence class methodsFor: 'loading' stamp: 'SeanDeNigris 6/6/2012 23:11'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSimplePersistence class methodsFor: 'loading' stamp: 'SeanDeNigris 6/6/2012 23:11'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSimplePersistence class methodsFor: 'loading' stamp: 'SeanDeNigris 6/6/2012 23:11'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSimplePersistence class methodsFor: 'accessing' stamp: 'SeanDeNigris 6/6/2012 23:11'!
project

	^self new project! !

!ConfigurationOfSimplePersistence class methodsFor: 'development support' stamp: 'SeanDeNigris 6/6/2012 23:11'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSimplePersistence methodsFor: 'baselines' stamp: 'SeanDeNigris 6/26/2012 12:03'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #'baseline'.
		spec repository: 'http://squeaksource.com/SimplePersistence'.
		spec 
			package: 'SimplePersistence-Core';
			package: 'SimplePersistence-Tests' with: [
				spec requires: #('SimplePersistence-Core' ). ].
		spec 
			group: 'default' with: #('SimplePersistence-Core' );
			group: 'Tests' with: #('SimplePersistence-Tests' ). ].
! !

!ConfigurationOfSimplePersistence methodsFor: 'baselines' stamp: 'SeanDeNigris 2/1/2013 16:24'!
baseline20: spec
	<version: '2.0-baseline'>

	spec for: #common do: [
		spec blessing: #'baseline'.
		spec description: 'Abstract and extract serialization; use Fuel under the covers'.
		spec repository: 'http://squeaksource.com/SimplePersistence'.
		spec 
			package: 'SimplePersistence-Core';
			package: 'SimplePersistence-Tests' with: [
				spec requires: #('SimplePersistence-Core' ). ].
		spec 
			group: 'default' with: #('SimplePersistence-Core' );
			group: 'Tests' with: #('SimplePersistence-Tests' ). ].
	
	spec for: #'pharo1.4.x' do: [	
		spec project: 'Fuel' with: [
			spec
				className: 'ConfigurationOfFuel';
				file: 'ConfigurationOfFuel';
				version: #'stable';
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec package: 'SimplePersistence-Core' with: [
				spec requires: #('Fuel' ). ] ].! !

!ConfigurationOfSimplePersistence methodsFor: 'symbolic versions' stamp: 'SeanDeNigris 2/1/2013 16:23'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.0'.
! !

!ConfigurationOfSimplePersistence methodsFor: 'accessing' stamp: 'SeanDeNigris 6/6/2012 23:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSimplePersistence methodsFor: 'versions' stamp: 'SeanDeNigris 2/1/2013 14:22'!
version101: spec
	<version: '1.0.1' imports: #('1.0-baseline' )>

	spec for: #'pharo1.4.x' do: [
		spec blessing: #'stable'.
		spec 
			package: 'SimplePersistence-Core' with: 'SimplePersistence-Core-SeanDeNigris.2';
			package: 'SimplePersistence-Tests' with: 'SimplePersistence-Tests-SeanDeNigris.1'. ].
! !

!ConfigurationOfSimplePersistence methodsFor: 'versions' stamp: 'SeanDeNigris 2/1/2013 14:21'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'initial development version'.
		spec author: 'SeanDeNigris'.
		spec timestamp: '6/6/2012 23:14'.
		spec 
			package: 'SimplePersistence-Core' with: 'SimplePersistence-Core-SeanDeNigris.1';
			package: 'SimplePersistence-Tests' with: 'SimplePersistence-Tests-SeanDeNigris.1'. ].
! !

!ConfigurationOfSimplePersistence methodsFor: 'versions' stamp: 'SeanDeNigris 2/4/2013 11:11'!
version20: spec
	<version: '2.0' imports: #('2.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
- Abstract and extract serialization; use Fuel under the covers
- Extract developer support behavior into separate class
- Fix developer support'.
		spec author: 'SeanDeNigris'.
		spec timestamp: '2/4/2013 11:11'.
		spec 
			package: 'SimplePersistence-Core' with: 'SimplePersistence-Core-SeanDeNigris.9';
			package: 'SimplePersistence-Tests' with: 'SimplePersistence-Tests-SeanDeNigris.2'. ].
! !
